DeskDataSourceException class

Base exception for CMS data source errors.

Implemented types
Implementers

Constructors

DeskDataSourceException(String message, [Object? cause])
const

Properties

cause Object?
Optional underlying error/exception
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited