menu
dart_desk package
documentation
dart_desk.dart
DeskOption class
DeskOption class
dark_mode
light_mode
DeskOption
class
abstract
Implementers
DeskRatingOption
TestDocumentRefDropdownOption
TestStringArrayOption
Constructors
DeskOption
({
bool
optional
=
false
,
DeskCondition
?
visibleWhen
})
const
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
optional
→
bool
Whether the field is optional (can be null/unset).
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
visibleWhen
→
DeskCondition
?
Condition that determines field visibility based on the editor context. When null, the field is always visible. When set, the field is rendered only if
visibleWhen.evaluate(ctx)
returns true.
final
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
dart_desk package
documentation
dart_desk
DeskOption class
dart_desk library