DocumentVersionList class

Paginated list of document versions.

Constructors

DocumentVersionList({required List<DocumentVersion> versions, required int total, required int page, required int pageSize})
const
DocumentVersionList.empty()
Creates an empty list
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hasNextPage bool
Whether there is a next page
no setter
hasPreviousPage bool
Whether there is a previous page
no setter
page int
Current page number (1-based)
final
pageSize int
Number of items per page
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
Total number of versions available
final
totalPages int
Total number of pages
no setter
versions List<DocumentVersion>
The list of versions
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited