DocumentVersionStatus enum

Status of a document version

Inheritance
Available extensions

Values

draft → const DocumentVersionStatus

Version is being edited and not visible to public

const DocumentVersionStatus('draft')
published → const DocumentVersionStatus

Version is published and visible to public

const DocumentVersionStatus('published')
archived → const DocumentVersionStatus

Version is archived and hidden from public

const DocumentVersionStatus('archived')
scheduled → const DocumentVersionStatus

Version is scheduled to be published at a future date

const DocumentVersionStatus('scheduled')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) DocumentVersionStatus
Parse from string value

Constants

values → const List<DocumentVersionStatus>
A constant List of the values in this enum, in order of their declaration.