menu
dart_desk package
documentation
dart_desk.dart
Hotspot class
Hotspot class
dark_mode
light_mode
Hotspot
class
Constructors
Hotspot
({
required
double
x
,
required
double
y
,
required
double
width
,
required
double
height
})
const
Hotspot.fromJson
(
Map
<
String
,
dynamic
>
json
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
override
height
→
double
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
width
→
double
final
x
→
double
final
y
→
double
final
Methods
copyWith
(
{
double
?
x
,
double
?
y
,
double
?
width
,
double
?
height
})
→
Hotspot
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
override
dart_desk package
documentation
dart_desk
Hotspot class
dart_desk library