DartDeskAuth class
A widget that provides authentication guard functionality using Serverpod's IDP authentication system with Google Sign-In and email/password support.
Reads a DartDeskAuthViewModel from GetIt. The caller is responsible for
registering the view model (and disposing it) before this widget mounts —
typically done once at app startup.
Example usage:
GetIt.I.registerSingleton(
DartDeskAuthViewModel.fromConfig(serverUrl: ..., apiKey: ...),
);
DartDeskAuth(
builder: (context, client, signOut) => MyAuthenticatedApp(
client: client,
onSignOut: signOut,
),
);
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DartDeskAuth
Constructors
- DartDeskAuth({Key? key, required Widget builder(BuildContext context, Client client, VoidCallback signOut), String title = 'Welcome to Dart Desk', String? subtitle, Widget? logo, ShadThemeData? theme})
-
const
Properties
- builder → Widget Function(BuildContext context, Client client, VoidCallback signOut)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- logo → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
final
- theme → ShadThemeData?
-
final
- title → String
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DartDeskAuth> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited