DeskBreakpoints class abstract final

CMS layout breakpoint names, used with ResponsiveBreakpoints.of(context).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

desktopTag → const String
mobile → const double
mobileTag → const String
tablet → const double
tabletTag → const String