DeskMarionetteConfig class abstract final

Static Marionette configuration for the CMS Studio.

Registers Shadcn UI components as interactive widgets so that Marionette can discover and interact with them.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

configuration → const MarionetteConfiguration