DraftEvent class

An autosave-draft event — emitted for any DocumentVersionStatus.draft version. Created by the backend's bucketed autosave (see spec 2026-05-03-version-history-autosaved-drafts-design.md).

Inheritance

Constructors

DraftEvent(DocumentVersion version)

Properties

authorUserId → String?
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
no setteroverride
version → DocumentVersion
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited