ImageHotspotEditor class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ImageHotspotEditor
Constructors
-
ImageHotspotEditor({Key? key, required String imageUrl, Hotspot? initialHotspot, CropRect? initialCrop, FramingMode initialMode = FramingMode.focus, double? initialScale, Offset? initialOffset, ValueChanged<
FramingMode> ? onModeChanged, required ValueChanged<({CropRect? crop, Hotspot? hotspot, Offset? offset, double? scale})> onChanged, ValueChanged<({CropRect? crop, Hotspot? hotspot, Offset? offset, double? scale})> ? onLiveChange, VoidCallback? onCancel}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageUrl → String
-
final
- initialCrop → CropRect?
-
final
- initialHotspot → Hotspot?
-
final
- initialMode → FramingMode
-
final
- initialOffset → Offset?
-
final
- initialScale → double?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onCancel → VoidCallback?
-
final
-
onChanged
→ ValueChanged<
({CropRect? crop, Hotspot? hotspot, Offset? offset, double? scale})> -
final
-
onLiveChange
→ ValueChanged<
({CropRect? crop, Hotspot? hotspot, Offset? offset, double? scale})> ? -
final
-
onModeChanged
→ ValueChanged<
FramingMode> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ImageHotspotEditor> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited