PublishedEvent class
A version publish event — emitted when a DocumentVersion transitions to DocumentVersionStatus.published.
- Inheritance
-
- Object
- HistoryEvent
- PublishedEvent
Constructors
- PublishedEvent(DocumentVersion version)
Properties
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
no setteroverride
- version → DocumentVersion
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited