FakeFilePickerPlatform class

A fake FilePicker for integration testing.

When installed, calls to FilePicker.platform.pickFiles return a tiny test PNG with bytes loaded, instead of opening the system file dialog.

Usage:

FakeFilePickerPlatform.install();
Inheritance
  • Object
  • PlatformInterface
  • FakeFilePickerPlatform
Mixed-in types
  • MockPlatformInterfaceMixin

Constructors

FakeFilePickerPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
resultToReturn ↔ FilePickerResult?
The result that pickFiles will return. Set to null to simulate user cancellation.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearTemporaryFiles() Future<bool?>
Asks the underlying platform to remove any temporary files created by this plugin.
inherited
getDirectoryPath({String? dialogTitle, bool lockParentWindow = false, String? initialDirectory}) Future<String?>
Selects a directory and returns its absolute path.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickFiles({String? dialogTitle, String? initialDirectory, FileType type = FileType.any, List<String>? allowedExtensions, dynamic onFileLoading(FilePickerStatus)?, bool allowCompression = true, int compressionQuality = 30, bool allowMultiple = false, bool withData = false, bool withReadStream = false, bool lockParentWindow = false, bool readSequential = false}) Future<FilePickerResult?>
Retrieves the file(s) from the underlying platform
saveFile({String? dialogTitle, String? fileName, String? initialDirectory, FileType type = FileType.any, List<String>? allowedExtensions, Uint8List? bytes, bool lockParentWindow = false}) Future<String?>
Opens a save file dialog which lets the user select a file path and a file name to save a file.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

install() FakeFilePickerPlatform
Installs this fake as the active FilePicker.platform.