getMultiVideoWithOptions method

Future<List<XFile>> getMultiVideoWithOptions({
  1. MultiVideoPickerOptions options = const MultiVideoPickerOptions(),
})
inherited

Returns a List<XFile> with the videos that were picked.

The videos come from the ImageSource.gallery.

The options argument controls additional settings that can be used when picking a video. See MultiVideoPickerOptions for more details.

If no videos were picked, returns an empty list.

Implementation

Future<List<XFile>> getMultiVideoWithOptions({
  MultiVideoPickerOptions options = const MultiVideoPickerOptions(),
}) {
  throw UnimplementedError(
    'getMultiVideoWithOptions() has not been implemented.',
  );
}