TestDocumentRefDropdownOption class
Context-aware multi-dropdown option that resolves options reactively from the documents of type 'test_all_fields' via DeskViewModel signals.
- Inheritance
-
- Object
- DeskOption
- DeskMultiDropdownOption<
String> - TestDocumentRefDropdownOption
Constructors
- TestDocumentRefDropdownOption()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initialValues
→ List<
String> ? -
no setteroverride
- maxSelected → int?
-
no setteroverride
- minSelected → int?
-
no setteroverride
- optional → bool
-
Whether the field is optional (can be null/unset).
finalinherited
- placeholder → String?
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visibleWhen → DeskCondition?
-
Condition that determines field visibility based on the editor context.
When null, the field is always visible. When set, the field is rendered
only if
visibleWhen.evaluate(ctx)returns true.finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
options(
BuildContext context) → List< DropdownOption< String> > -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited