DartDeskApp class
Entry point for Dart Desk CMS applications.
Two constructors for different auth strategies:
Built-in Serverpod IDP auth (Google + email/password):
DartDeskApp(
serverUrl: 'http://localhost:8080/',
config: DartDeskConfig(
documentTypes: [...],
documentTypeDecorations: [...],
),
)
External auth (Firebase, Clerk, Auth0, etc.):
DartDeskApp.withDataSource(
dataSource: myDataSource,
onSignOut: () => myAuth.signOut(),
config: DartDeskConfig(
documentTypes: [...],
documentTypeDecorations: [...],
),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DartDeskApp
Constructors
- DartDeskApp({Key? key, required String serverUrl, required DartDeskConfig config, required String apiKey, ShadThemeData? theme})
-
Creates a DartDeskApp with built-in Serverpod IDP authentication.
const
- DartDeskApp.withDataSource({Key? key, required DataSource dataSource, required VoidCallback onSignOut, required DartDeskConfig config, ShadThemeData? theme})
-
Creates a DartDeskApp with an external data source and auth.
const
Properties
- apiKey → String?
-
final
- config → DartDeskConfig
-
final
- dataSource → DataSource?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onSignOut → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverUrl → String?
-
final
- theme → ShadThemeData?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DartDeskApp> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited