menu
dart_desk package
documentation
studio.dart
DeskRatingOption class
DeskRatingOption class
dark_mode
light_mode
DeskRatingOption
class
Inheritance
Object
DeskOption
DeskRatingOption
Constructors
DeskRatingOption
({
int
maxRating
=
5
,
IconData
icon
=
FontAwesomeIcons.solidStar
})
const
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
icon
→
IconData
final
maxRating
→
int
final
optional
→
bool
Whether the field is optional (can be null/unset).
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
visibleWhen
→
DeskCondition
?
Condition that determines field visibility based on the editor context. When null, the field is always visible. When set, the field is rendered only if
visibleWhen.evaluate(ctx)
returns true.
final
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
dart_desk package
documentation
studio
DeskRatingOption class
studio library