ImageTransformParams class

Constructors

ImageTransformParams({int? width, int? height, FitMode? fit, String? format, int? quality, double? fpX, double? fpY, CropRect? crop})
const

Properties

crop CropRect?
final
fit FitMode?
final
format String?
final
fpX double?
final
fpY double?
final
hashCode int
The hash code for this object.
no setterinherited
height int?
final
quality int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited