StudioConfig class
Holds CMS studio configuration data.
Registered as a GetIt singleton by DeskStudioApp before the widget tree
builds. All widgets that previously received StudioCoordinator as a
parameter now read from GetIt.I<StudioConfig>() instead.
Constructors
-
StudioConfig({required List<
DocumentType< documentTypes, required DataSource dataSource, List<Serializable> >DocumentTypeDecoration> documentTypeDecorations = const [], VoidCallback? onSignOut}) -
const
Properties
- dataSource → DataSource
-
final
-
documentTypeDecorations
→ List<
DocumentTypeDecoration> -
final
-
documentTypes
→ List<
DocumentType< Serializable> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onSignOut → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited